@@ -3,8 +3,8 @@ package HTML::FormFu::Attribute;
 use strict;
 use warnings;
 use Exporter qw/ import /;
-use HTML::FormFu::Util qw/ 
-    append_xml_attribute remove_xml_attribute literal require_class 
+use HTML::FormFu::Util qw/
+    append_xml_attribute remove_xml_attribute literal require_class
     _parse_args /;
 use List::MoreUtils qw/ uniq /;
 use Scalar::Util qw/ weaken /;
@@ -184,43 +184,43 @@ sub mk_del_attrs {
 
 sub mk_add_methods {
     my ( $self, @names ) = @_;
-    
+
     my $class = ref $self || $self;
-    
+
     for my $name (@names) {
         my $sub = sub {
             my ( $self, $arg ) = @_;
             my @return;
             my $sub_name = "_single_$name";
-        
+
             if ( ref $arg eq 'ARRAY' ) {
                 push @return, map { $self->$sub_name($_) } @$arg;
             }
             else {
                 push @return, $self->$sub_name($arg);
             }
-        
+
             return @return == 1 ? $return[0] : @return;
-            };
-        
+        };
+
         no strict 'refs';
-        
+
         *{"$class\::$name"} = $sub;
     }
-    
+
     return;
 }
 
 sub mk_single_methods {
     my ( $self, @names ) = @_;
-    
+
     my $class = ref $self || $self;
-    
+
     for my $name (@names) {
         my $sub = sub {
             my ( $self, $arg ) = @_;
             my @items;
-        
+
             if ( ref $arg eq 'HASH' ) {
                 push @items, $arg;
             }
@@ -230,27 +230,26 @@ sub mk_single_methods {
             else {
                 croak 'invalid args';
             }
-        
+
             my @return;
-        
+
             for my $item (@items) {
-                my @names = 
-                    map { ref $_ ? @$_ : $_}
-                    grep { defined }
+                my @names = map { ref $_ ? @$_ : $_ }
+                    grep {defined}
                     ( delete $item->{name}, delete $item->{names} );
-        
-                @names = uniq map { $_->name } grep { defined $_->name } 
-                    @{ $self->get_fields }
+
+                @names = uniq map { $_->name }
+                    grep { defined $_->name } @{ $self->get_fields }
                     if !@names;
-        
+
                 croak "no field names to add $name to" if !@names;
-                
+
                 my $type = delete $item->{type};
-        
+
                 for my $x (@names) {
-                    my $require_sub = "_require_$name";
+                    my $require_sub  = "_require_$name";
                     my $array_method = "_${name}s";
-                    
+
                     for my $field ( @{ $self->get_fields( { name => $x } ) } ) {
                         my $new = $field->$require_sub( $type, $item );
                         push @{ $field->$array_method }, $new;
@@ -258,120 +257,117 @@ sub mk_single_methods {
                     }
                 }
             }
-        
+
             return @return;
-            };
-        
+        };
+
         no strict 'refs';
-        
+
         *{"$class\::_single_$name"} = $sub;
     }
-    
+
     return;
 }
 
 sub mk_require_methods {
     my ( $self, @names ) = @_;
-    
+
     my $class = ref $self || $self;
-    
-    for my $name (@names) {    
+
+    for my $name (@names) {
         my $sub = sub {
             my ( $self, $type, $opt ) = @_;
-        
+
             croak 'required arguments: $self, $type, \%options' if @_ != 3;
-        
+
             eval { my %x = %$opt };
             croak "options argument must be hash-ref" if $@;
-        
+
             my $class = $type;
             if ( not $class =~ s/^\+// ) {
                 $class = "HTML::FormFu::" . ucfirst($name) . "::$class";
             }
 
             $type =~ s/^\+//;
-            
+
             require_class($class);
-            
-            my $type_method = $name eq 'element'
-                ? "${name}_type" : 'type';
-        
+
             my $object = $class->new( {
-                    $type_method => $type,
-                    parent       => $self,
+                    type   => $type,
+                    parent => $self,
                 } );
-        
+
             weaken( $object->{parent} );
-        
+
             # inlined ObjectUtil::populate(), otherwise circular dependency
             eval {
                 map { $object->$_( $opt->{$_} ) } keys %$opt;
             };
             croak $@ if $@;
-        
+
             return $object;
-            };
-        
+        };
+
         no strict 'refs';
-        
+
         *{"$class\::_require_$name"} = $sub;
-}
-    
+    }
+
     return;
 }
 
 sub mk_get_methods {
     my ( $self, @names ) = @_;
-    
+
     my $class = ref $self || $self;
-    
+
     for my $name (@names) {
         my $sub = sub {
-            my $self = shift;
-            my %args = _parse_args(@_);
+            my $self       = shift;
+            my %args       = _parse_args(@_);
             my $get_method = "get_${name}s";
-            
+
             my @x = map { @{ $_->$get_method(@_) } } @{ $self->_elements };
-            
+
             if ( exists $args{name} ) {
                 @x = grep { $_->name eq $args{name} } @x;
             }
-            
+
             if ( exists $args{type} ) {
                 @x = grep { $_->type eq $args{type} } @x;
             }
-            
+
             return \@x;
-            };
-        
+        };
+
         no strict 'refs';
-        
+
         *{"$class\::get_${name}s"} = $sub;
-}
-    
+    }
+
     return;
 }
 
 sub mk_get_one_methods {
     my ( $self, @names ) = @_;
-    
+
     my $class = ref $self || $self;
-    
+
     for my $name (@names) {
         my $sub = sub {
-            my $self = shift;
+            my $self       = shift;
             my $get_method = "get_${name}s";
-            
+
             my $x = $self->$get_method(@_);
-        
+
             return @$x ? $x->[0] : ();
-            };
-           
+        };
+
         no strict 'refs';
-        
+
         *{"$class\::get_$name"} = $sub;
-}
-    
+    }
+
     return;
 }
 
