@@ -1,23 +1,21 @@
 package HTML::FormFu::Constraint::CallbackOnce;
 
-use Moose;
-extends 'HTML::FormFu::Constraint';
+use strict;
+use warnings;
+use base 'HTML::FormFu::Constraint';
 
-has callback => ( is => 'rw', traits => ['Chained'] );
+__PACKAGE__->mk_accessors(qw/ callback /);
 
 sub process {
     my ( $self, $params ) = @_;
 
-    # check when condition
-    return if !$self->_process_when($params);
+    my $name = $self->name;
 
-    my $value = $self->get_nested_hash_value( $params, $self->nested_name );
+    my $value = $params->{$name};
 
     my $callback = $self->callback || sub {1};
 
-    no strict 'refs';
-
-    my $ok = eval { $callback->( $value, $params ) };
+    my $ok = eval { $callback->( $value, $params ); };
 
     return $self->mk_errors( {
             pass => ( $@ or !$ok ) ? 0 : 1,
@@ -25,15 +23,13 @@ sub process {
         } );
 }
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 
 __END__
 
 =head1 NAME
 
-HTML::FormFu::Constraint::CallbackOnce - Code Callback Constraint
+HTML::FormFu::Constraint::CallbackOnce
 
 =head1 SYNOPSIS
 
@@ -71,7 +67,7 @@ Arguments: \&sub_ref
 
 Is a sub-class of, and inherits methods from L<HTML::FormFu::Constraint>
 
-L<HTML::FormFu>
+L<HTML::FormFu::FormFu>
 
 =head1 AUTHOR
 
@@ -81,5 +77,3 @@ Carl Franks C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
-
-=cut
