@@ -3,6 +3,7 @@ package HTML::FormFu::Constraint::Set;
 use strict;
 use warnings;
 use base 'HTML::FormFu::Constraint';
+use Class::C3;
 
 use Storable qw/ dclone /;
 
@@ -22,12 +23,12 @@ sub constrain_value {
 
 sub clone {
     my $self = shift;
-    
-    my $clone = $self->SUPER::clone(@_);
-    
+
+    my $clone = $self->next::method(@_);
+
     $clone->set( dclone $self->set )
         if $self->set;
-    
+
     return $clone;
 }
 
