@@ -8,23 +8,23 @@ __PACKAGE__->mk_accessors(qw/ _filename /);
 
 sub parse_uploads {
     my ( $class, $form, $name ) = @_;
-    
+
     my @params = $form->query->param($name);
     my @new;
-    
+
     for my $param (@params) {
         if ( my $file = $form->query->upload($param) ) {
-            $param = $class->new({
-                _param    => $file,
-                _filename => $param,
-                parent    => $form,
-                });
+            $param = $class->new( {
+                    _param    => $file,
+                    _filename => $param,
+                    parent    => $form,
+                } );
         }
         push @new, $param;
     }
-    
+
     return if !@new;
-    
+
     return @new == 1 ? $new[0] : \@new;
 }
 
@@ -32,8 +32,10 @@ sub headers {
     my ($self) = @_;
 
     my %header = (
-        'Content-Type'   => $self->form->query->upload_info( $self->_filename, 'mime' ),
-        'Content-Length' => $self->form->query->upload_info( $self->_filename, 'size' ),
+        'Content-Type' =>
+            $self->form->query->upload_info( $self->_filename, 'mime' ),
+        'Content-Length' =>
+            $self->form->query->upload_info( $self->_filename, 'size' ),
     );
 
     return \%header;
@@ -41,13 +43,13 @@ sub headers {
 
 sub filename {
     my ($self) = @_;
-    
+
     return $self->_filename;
 }
 
 sub fh {
     my ($self) = @_;
-    
+
     return $self->form->query->upload( $self->_filename );
 }
 
